TransactionBroadcast class
Result of a transaction broadcast operation.
Constructors
- TransactionBroadcast({required String operationId, required Stream stream})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operationId → String
-
The unique operation ID for this broadcast.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stream → Stream
-
Stream of events related to this broadcast.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited