blockHash property

String? get blockHash

Returns the block hash if the transaction is in a block or finalized.

Returns null for other status types or if the block hash is not available.

Example:

if (status.isFinalized) {
  print('Finalized in block: ${status.blockHash}');
}

Implementation

String? get blockHash {
  if (value is String) return value as String;
  if (value is Map && value.containsKey('blockHash')) {
    return value['blockHash'] as String;
  }
  return null;
}