isInBlock property

bool get isInBlock

Returns true if the transaction is included in a block (but not yet finalized).

The block may still be reorganized, so this is not a guarantee of finality. Use blockHash to get the block hash.

Implementation

bool get isInBlock => type.toLowerCase() == 'inblock';