StorageResultItem class

A single storage item returned by a storage() operation.

Constructors

StorageResultItem({required String key, String? value, String? hash})
const
StorageResultItem.fromJson(Map<String, dynamic> json)
factory

Properties

hash String?
The storage hash, if queried with type "hash".
final
hashCode int
The hash code for this object.
no setterinherited
key String
The storage key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
The storage value (hex-encoded), if queried with type "value".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited