ChainHeadApi<P extends Provider> class
ChainHead API for the new Substrate JSON-RPC specification.
The chainHead API uses a follow/unfollow session model. Calling follow creates a ChainHeadSession that wraps the subscription and provides typed methods for querying block data.
Reference: https://paritytech.github.io/json-rpc-interface-spec/api/chainHead.html
Constructors
- ChainHeadApi(P _provider)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
follow(
{bool withRuntime = false}) → Future< ChainHeadSession< P> > - Start following the chain head.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited