unfollow method
Stop the follow subscription.
After calling this method, the session is no longer active and no further operations can be performed.
Implementation
Future<void> unfollow() async {
if (_unfollowed) return;
_unfollowed = true;
final response = await _provider.send('chainHead_v1_unfollow', [followSubscriptionId]);
if (response.error != null) {
throw Exception(response.error.toString());
}
}