ChainSpecApi<P extends Provider> class
ChainSpec API for the new Substrate JSON-RPC specification.
Provides methods to query chain specification information such as the genesis hash, chain name, and chain properties.
Reference: https://paritytech.github.io/json-rpc-interface-spec/api/chainSpec.html
Constructors
- ChainSpecApi(P _provider)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chainName(
) → Future< String> - Returns the human-readable name of the chain.
-
genesisHash(
) → Future< String> - Returns the hash of the genesis block of the chain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
properties(
) → Future< Map< String, dynamic> > - Returns the chain properties as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited