TransactionApi<P extends Provider> class
Transaction API for the new Substrate JSON-RPC specification.
Provides methods to broadcast and manage transactions using the
subscription-based transaction_v1_* RPC methods.
Reference: https://paritytech.github.io/json-rpc-interface-spec/api/transaction.html
Constructors
- TransactionApi(P _provider)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
broadcast(
Uint8List extrinsic) → Future< TransactionBroadcast> - Broadcasts a transaction to the network.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stop(
String operationId) → Future< void> - Stops an ongoing broadcast operation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited