ChainHeadOperationResult class
Result of a chainHead operation that returns an operationId.
Constructors
- ChainHeadOperationResult({required String result, String? operationId})
-
const
-
ChainHeadOperationResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLimitReached → bool
-
no setter
- isStarted → bool
-
no setter
- operationId → String?
-
final
- result → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited