Returns true if the transaction is included in a block (but not yet finalized).
true
The block may still be reorganized, so this is not a guarantee of finality. Use blockHash to get the block hash.
bool get isInBlock => type.toLowerCase() == 'inblock';